summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--apt/package.py9
-rw-r--r--debian/changelog4
2 files changed, 9 insertions, 4 deletions
diff --git a/debian/changelog b/debian/changelog
index 23f586d9..f9a26c49 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -9,7 +9,9 @@ python-apt (0.6.16.2) unstable; urgency=low
- fix various pychecker warnings
* apt/cache.py:
- return useful values on Cache.update()
- * apt/cache.py, apt/package.py: fix various pychecker warnings
+ * apt/package.py:
+ - fix various pychecker warnings
+ - added setDelete(purge) option
--
diff --git a/apt/package.py b/apt/package.py
index 4fceb904..66bfd72b 100644
--- a/apt/package.py
+++ b/apt/package.py
@@ -274,10 +274,13 @@ class Package(object):
self._pcache.cachePreChange()
self._depcache.MarkKeep(self._pkg)
self._pcache.cachePostChange()
- def markDelete(self, autoFix=True):
- """ mark a package for delete. Run the resolver if autoFix is set """
+ def markDelete(self, autoFix=True, purge=False):
+ """ mark a package for delete. Run the resolver if autoFix is set.
+ Mark the package as purge (remove with configuration) if 'purge'
+ is set.
+ """
self._pcache.cachePreChange()
- self._depcache.MarkDelete(self._pkg)
+ self._depcache.MarkDelete(self._pkg, purge)
# try to fix broken stuffsta
if autoFix and self._depcache.BrokenCount > 0:
Fix = apt_pkg.GetPkgProblemResolver(self._depcache)